@@ -3,14 +3,17 @@ from pathlib import Path
 
 import jupytext
 
-from jupyter_ascending import server_multiplexer
+from jupyter_ascending.handlers import jupyter_server
 from jupyter_ascending.json_requests import SyncRequest
+from jupyter_ascending.logger import J_LOGGER
 
 
+@J_LOGGER.catch
 def send(file_name: str, fmt: str = "py:percent", force_update: bool = False):
     if ".synced.py" not in file_name:
         return
 
+    J_LOGGER.info(f"Syncing File: {file_name}...")
     file_name = str(Path(file_name).absolute())
 
     notebook_name = file_name.replace(".synced.py", ".synced.ipynb")
@@ -26,7 +29,9 @@ def send(file_name: str, fmt: str = "py:percent", force_update: bool = False):
             writer.write(notebook_contents + "\n")
 
     request_obj = SyncRequest(file_name=file_name, contents=raw_result)
-    server_multiplexer.request_notebook_command(request_obj)
+    jupyter_server.request_notebook_command(request_obj)
+
+    J_LOGGER.info("... Complete")
 
 
 if __name__ == "__main__":
